@@ -2,7 +2,7 @@
 
 let _ =
   begin
-    match with_regexp "" with
+    Regexp.match "" with
       "AB" -> ()
     | _ -> ()
   end;
@@ -10,7 +10,7 @@ let _ =
     let module M = struct
       let v () = 
 	begin
-	  match with_regexp "" with
+	  Regexp.match "" with
 	    "AB" -> ()
 	  | _ -> ()
 	end;
@@ -20,7 +20,7 @@ let _ =
 
 let _ =
   begin
-    match with_regexp "" with
+    Regexp.match "" with
       "AB" -> ()
     | _ -> ()
   end
